@@ -1095,6 +1095,45 @@ class Address(object):
             return self.pywaves.wrapper('/transactions/broadcast', data)
 
     def setCompiledScript(self, script, txFee=pywaves.DEFAULT_SCRIPT_FEE, timestamp=0, publicKey=None):
+        if not self.privateKey:
+            msg = 'Private key required'
+            logging.error(msg)
+            self.pywaves.throw_error(msg)
+        else:
+            setScriptTransaction = transaction_pb2.SetScriptTransactionData()
+            setScriptTransaction.script = base64.b64decode(script)
+
+            if timestamp == 0:
+                timestamp = int(time.time() * 1000)
+
+            tx_fee = amount_pb2.Amount()
+            tx_fee.amount = txFee
+            transaction = transaction_pb2.Transaction()
+            transaction.chain_id = ord(self.pywaves.CHAIN_ID)
+            transaction.sender_public_key = base58.b58decode(self.publicKey)
+            transaction.fee.CopyFrom(tx_fee)
+            transaction.timestamp = timestamp
+            transaction.version = 2
+            transaction.set_script.CopyFrom(setScriptTransaction)
+
+            signature = crypto.sign(self.privateKey, transaction.SerializeToString())
+            print(transaction.SerializeToString())
+
+            jsonMessage = json.loads('{}')
+            jsonMessage['type'] = 13
+            jsonMessage['proofs'] = [ signature ]
+            jsonMessage['senderPublicKey'] = self.publicKey
+            jsonMessage['fee'] = tx_fee.amount
+            jsonMessage['timestamp'] = timestamp
+            jsonMessage['chainId'] = ord(self.pywaves.CHAIN_ID)
+            jsonMessage['version'] = 2
+            jsonMessage['script'] = script
+
+            req = self.pywaves.wrapper('/transactions/broadcast', json.dumps(jsonMessage))
+
+            return req
+
+    '''def setCompiledScript(self, script, txFee=pywaves.DEFAULT_SCRIPT_FEE, timestamp=0, publicKey=None):
         #script = self.pywaves.wrapper('/utils/script/compileCode', scriptSource)['script'][7:]
         if not self.privateKey:
             msg = 'Private key required'
@@ -1130,47 +1169,12 @@ class Address(object):
                     signature
                 ]
             })
-            return self.pywaves.wrapper('/transactions/broadcast', data)
+            return self.pywaves.wrapper('/transactions/broadcast', data)'''
 
     def setScript(self, scriptSource, txFee=pywaves.DEFAULT_SCRIPT_FEE, timestamp=0, publicKey=None):
         script = self.pywaves.wrapper('/utils/script/compileCode', scriptSource)['script'][7:]
 
         return self.setCompiledScript(script, txFee, timestamp, publicKey)
-        '''if not self.privateKey:
-            msg = 'Private key required'
-            logging.error(msg)
-            self.pywaves.throw_error(msg)
-        else:
-            compiledScript = base64.b64decode(script)
-            scriptLength = len(compiledScript)
-            if timestamp == 0:
-                timestamp = int(time.time() * 1000)
-
-            if not publicKey:
-                publicKey = self.publicKey
-            sData = b'\x0d' + \
-                    b'\1' + \
-                    crypto.str2bytes(str(self.pywaves.CHAIN_ID)) + \
-                    base58.b58decode(publicKey) + \
-                    b'\1' + \
-                    struct.pack(">H", scriptLength) + \
-                    compiledScript + \
-                    struct.pack(">Q", txFee) + \
-                    struct.pack(">Q", timestamp)
-            signature = crypto.sign(self.privateKey, sData)
-
-            data = json.dumps({
-                "type": 13,
-                "version": 1,
-                "senderPublicKey": publicKey,
-                "fee": txFee,
-                "timestamp": timestamp,
-                "script": 'base64:' + script,
-                "proofs": [
-                    signature
-                ]
-            })
-            return self.pywaves.wrapper('/transactions/broadcast', data)'''
 
     def setAssetScript(self, asset, scriptSource, txFee=pywaves.DEFAULT_ASSET_SCRIPT_FEE, timestamp=0):
         script = self.pywaves.wrapper('/utils/script/compile', scriptSource)['script'][7:]
