@@ -6,7 +6,8 @@ class Oracle(object):
     def __init__(self, oracleAddress = None, seed = None, pywaves=pw):
         self.pw = pywaves
         if seed != None:
-            self.oracleAddress = self.pw.Address(seed=seed)
+            self.oracleAcc = self.pw.Address(seed=seed)
+            self.oracleAddress =  self.oracleAcc.address
         else:
             self.oracleAddress = oracleAddress
 
@@ -36,4 +37,4 @@ class Oracle(object):
             'value': dataEntry
         }]
 
-        return self.oracleAddress.dataTransaction(dataToStore,minimalFee=minimalFee)
+        return self.oracleAcc.dataTransaction(dataToStore,minimalFee=minimalFee)
